@@ -17,14 +17,25 @@
 import requests
 from six.moves.urllib.parse import parse_qs, urljoin
 
-from .common import (CANCELLED, ERROR, PAID, URL, WAITING, PaymentCommon,
-                     PaymentException, PaymentResponse, ResponseError, _)
+from .common import (
+    CANCELLED,
+    ERROR,
+    PAID,
+    URL,
+    WAITING,
+    PaymentCommon,
+    PaymentException,
+    PaymentResponse,
+    ResponseError,
+    _,
+)
 
 __all__ = ['Payment']
 
 
 class Payment(PaymentCommon):
     '''Implements EMS API, see https://dev.online.emspay.eu/.'''
+
     service_url = 'https://api.online.emspay.eu/v1/'
 
     description = {
@@ -67,7 +78,7 @@ class Payment(PaymentCommon):
                 'email_address': email,
                 'first_name': first_name,
                 'last_name': last_name,
-            }
+            },
         }
 
         resp = self.call_endpoint('POST', 'orders', data=body)
@@ -98,7 +109,7 @@ class Payment(PaymentCommon):
             order_id=order_id,
             transaction_id=order_id,
             bank_status=status,
-            test=bool('is-test' in resp.get('flags', []))
+            test=bool('is-test' in resp.get('flags', [])),
         )
         return response
 
@@ -120,12 +131,12 @@ class Payment(PaymentCommon):
             result = response.json()
         except ValueError:
             self.logger.debug('received invalid json %r', response.text)
-            raise PaymentException('%s on endpoint "%s" returned invalid JSON: %s' %
-                                   (method, endpoint, response.text))
+            raise PaymentException(
+                '%s on endpoint "%s" returned invalid JSON: %s' % (method, endpoint, response.text)
+            )
         self.logger.debug('received "%s" with status %s', result, response.status_code)
         try:
             response.raise_for_status()
         except requests.exceptions.HTTPError as e:
-            raise PaymentException(
-                '%s error on endpoint "%s": %s "%s"' % (method, endpoint, e, result))
+            raise PaymentException('%s error on endpoint "%s": %s "%s"' % (method, endpoint, e, result))
         return result
