@@ -14,18 +14,19 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from six.moves.urllib.parse import urlparse, parse_qs
 import datetime
 
-import eopayment
 import pytest
+from six.moves.urllib.parse import parse_qs, urlparse
+
+import eopayment
 
 
 @pytest.fixture
 def backend():
     options = {
         'automatic_notification_url': 'http://example.com/direct_notification_url',
-        'origin': 'Mairie de Perpette-les-oies'
+        'origin': 'Mairie de Perpette-les-oies',
     }
     return eopayment.Payment('dummy', options)
 
@@ -33,7 +34,8 @@ def backend():
 def test_request(backend, freezer):
     freezer.move_to('2020-01-01 00:00:00+01:00')
     transaction_id, method, raw_url = backend.request(
-        '10.10', capture_date=datetime.date(2020, 1, 7), subject='Repas pour 4 personnes')
+        '10.10', capture_date=datetime.date(2020, 1, 7), subject='Repas pour 4 personnes'
+    )
     assert transaction_id
     assert method == 1
     url = urlparse(raw_url)
