@@ -18,14 +18,11 @@ import json
 
 import pytest
 import requests
-import six
-from httmock import response, urlmatch, HTTMock, with_httmock, all_requests, remember_called
+from httmock import HTTMock, all_requests, remember_called, response, urlmatch, with_httmock
 
 import eopayment
 from eopayment.keyware import Payment
 
-pytestmark = pytest.mark.skipif(six.PY2, reason='this payment module only supports python3')
-
 WEBHOOK_URL = 'https://callback.example.com'
 RETURN_URL = 'https://return.example.com'
 API_KEY = 'test'
@@ -36,9 +33,7 @@ QUERY_STRING = 'order_id=' + ORDER_ID
 
 POST_ORDER_RESPONSE = {
     "amount": 995,
-    "client": {
-        "user_agent": "Testing API"
-    },
+    "client": {"user_agent": "Testing API"},
     "created": "2016-07-04T11:41:57.121017+00:00",
     "currency": "EUR",
     "description": "Example description",
@@ -47,14 +42,12 @@ POST_ORDER_RESPONSE = {
     "modified": "2016-07-04T11:41:57.183822+00:00",
     "order_url": "https://api.online.emspay.eu/pay/1c969951-f5f1-4290-ae41-6177961fb3cb/",
     "project_id": "1ef558ed-d77d-470d-b43b-c0f4a131bcef",
-    "status": "new"
+    "status": "new",
 }
 
 GET_ORDER_RESPONSE = {
     "amount": 995,
-    "client": {
-        "user_agent": "Testing API"
-    },
+    "client": {"user_agent": "Testing API"},
     "created": "2016-07-04T11:41:55.635115+00:00",
     "currency": "EUR",
     "description": "Example order #1",
@@ -80,7 +73,7 @@ GET_ORDER_RESPONSE = {
                     "id": "0c4bd0cd-f197-446b-b218-39cbeb028290",
                     "noticed": "2016-07-04T11:41:55.987468+00:00",
                     "occurred": "2016-07-04T11:41:55.831655+00:00",
-                    "source": "set_status"
+                    "source": "set_status",
                 }
             ],
             "expiration_period": "PT60M",
@@ -94,9 +87,9 @@ GET_ORDER_RESPONSE = {
             },
             "payment_url": "https://api.online.emspay.eu/redirect/6c81499c-14e4-4974-99e5-fe72ce019411/to/payment/",
             "project_id": "1ef558ed-d77d-470d-b43b-c0f4a131bcef",
-            "status": "completed"
+            "status": "completed",
         }
-    ]
+    ],
 }
 
 
@@ -105,11 +98,13 @@ GET_ORDER_RESPONSE = {
 def add_order(url, request):
     return response(200, POST_ORDER_RESPONSE, request=request)
 
+
 @remember_called
 @urlmatch(scheme='https', netloc='api.online.emspay.eu', path='/v1/orders', method='GET')
 def successful_order(url, request):
     return response(200, GET_ORDER_RESPONSE, request=request)
 
+
 @remember_called
 @urlmatch(scheme='https', netloc='api.online.emspay.eu', path=r'/v1/orders', method='DELETE')
 def cancelled_order(url, request):
@@ -117,6 +112,7 @@ def cancelled_order(url, request):
     resp['status'] = 'cancelled'
     return response(200, resp, request=request)
 
+
 @remember_called
 @urlmatch(scheme='https', netloc='api.online.emspay.eu', path='/v1/orders')
 def error_order(url, request):
@@ -124,29 +120,35 @@ def error_order(url, request):
     resp['status'] = 'error'
     return response(200, resp, request=request)
 
+
 @remember_called
 @urlmatch(scheme='https', netloc='api.online.emspay.eu', path='/v1/orders', method='GET')
 def connection_error(url, request):
     raise requests.ConnectionError('test msg')
 
+
 @remember_called
 @urlmatch(scheme='https', netloc='api.online.emspay.eu', path='/v1/orders', method='GET')
 def http_error(url, request):
     error_payload = {'error': {'status': 400, 'type': 'Bad request', 'value': 'error'}}
     return response(400, error_payload, request=request)
 
+
 @remember_called
 @urlmatch(scheme='https', netloc='api.online.emspay.eu', path='/v1/orders', method='GET')
 def invalid_json(url, request):
     return response(200, '{', request=request)
 
+
 @pytest.fixture
 def keyware():
-    return Payment({
-        'normal_return_url': RETURN_URL,
-        'automatic_return_url': WEBHOOK_URL,
-        'api_key': API_KEY,
-    })
+    return Payment(
+        {
+            'normal_return_url': RETURN_URL,
+            'automatic_return_url': WEBHOOK_URL,
+            'api_key': API_KEY,
+        }
+    )
 
 
 @with_httmock(add_order)
