@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # eopayment - online payment library
 # Copyright (C) 2011-2020 Entr'ouvert
 #
@@ -16,57 +15,59 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 
-import codecs
-from unittest import TestCase
-from decimal import Decimal
 import base64
-import mock
-import six
-from six.moves.urllib import parse as urllib
+import codecs
+from decimal import Decimal
+from unittest import TestCase, mock
 from xml.etree import ElementTree as ET
 
-import eopayment.paybox as paybox
-import eopayment
+import pytest
+from six.moves.urllib import parse as urllib
 
+import eopayment
+import eopayment.paybox as paybox
 
 BACKEND_PARAMS = {
-    'platform': u'test',
-    'site': u'12345678',
-    'rang': u'001',
-    'identifiant': u'12345678',
+    'platform': 'test',
+    'site': '12345678',
+    'rang': '001',
+    'identifiant': '12345678',
     'shared_secret': (
-        u'0123456789ABCDEF0123456789ABCDEF01234'
-        u'56789ABCDEF0123456789ABCDEF0123456789'
-        u'ABCDEF0123456789ABCDEF0123456789ABCDE'
-        u'F0123456789ABCDEF'
+        '0123456789ABCDEF0123456789ABCDEF01234'
+        '56789ABCDEF0123456789ABCDEF0123456789'
+        'ABCDEF0123456789ABCDEF0123456789ABCDE'
+        'F0123456789ABCDEF'
     ),
-    'automatic_return_url': u'http://example.com/callback',
+    'automatic_return_url': 'http://example.com/callback',
 }
 
 
 class PayboxTests(TestCase):
-    if six.PY2:
-        def assertRaisesRegex(self, *args, **kwargs):
-            return self.assertRaisesRegexp(*args, **kwargs)
-
     def test_sign(self):
-        key = (b'0123456789ABCDEF0123456789ABCDEF0123456789'
-               b'ABCDEF0123456789ABCDEF0123456789ABCDEF0123'
-               b'456789ABCDEF0123456789ABCDEF0123456789ABCD'
-               b'EF')
+        key = (
+            b'0123456789ABCDEF0123456789ABCDEF0123456789'
+            b'ABCDEF0123456789ABCDEF0123456789ABCDEF0123'
+            b'456789ABCDEF0123456789ABCDEF0123456789ABCD'
+            b'EF'
+        )
         key = codecs.decode(key, 'hex')
-        d = dict(paybox.sign([
-            ['PBX_SITE', u'12345678'],
-            ['PBX_RANG', u'32'],
-            ['PBX_IDENTIFIANT', u'12345678'],
-            ['PBX_TOTAL', u'999'],
-            ['PBX_DEVISE', u'978'],
-            ['PBX_CMD', u'appel à Paybox'],
-            ['PBX_PORTEUR', u'test@paybox.com'],
-            ['PBX_RETOUR', u'Mt:M;Ref:R;Auto:A;Erreur:E'],
-            ['PBX_HASH', u'SHA512'],
-            ['PBX_TIME', u'2015-06-08T16:21:16+02:00'],
-        ], key))
+        d = dict(
+            paybox.sign(
+                [
+                    ['PBX_SITE', '12345678'],
+                    ['PBX_RANG', '32'],
+                    ['PBX_IDENTIFIANT', '12345678'],
+                    ['PBX_TOTAL', '999'],
+                    ['PBX_DEVISE', '978'],
+                    ['PBX_CMD', 'appel à Paybox'],
+                    ['PBX_PORTEUR', 'test@paybox.com'],
+                    ['PBX_RETOUR', 'Mt:M;Ref:R;Auto:A;Erreur:E'],
+                    ['PBX_HASH', 'SHA512'],
+                    ['PBX_TIME', '2015-06-08T16:21:16+02:00'],
+                ],
+                key,
+            )
+        )
         result = (
             '7E74D8E9A0DBB65AAE51C5C50C2668FD98FC99AED'
             'F18244BB1935F602B6C2E953B61FD84364F34FDB8'
@@ -84,8 +85,13 @@ class PayboxTests(TestCase):
         transaction = '1234'
         amount = '19.99'
         transaction_id, kind, what = backend.request(
-            Decimal(amount), email=email, orderid=order_id,
-            transaction_id=transaction, time=time, manual_validation=False)
+            Decimal(amount),
+            email=email,
+            orderid=order_id,
+            transaction_id=transaction,
+            time=time,
+            manual_validation=False,
+        )
         self.assertEqual(kind, eopayment.FORM)
         self.assertEqual(transaction_id, '%s!%s' % (transaction, order_id))
         root = ET.fromstring(str(what))
@@ -114,16 +120,16 @@ class PayboxTests(TestCase):
             ),
             'PBX_ARCHIVAGE': '20160216',
             'PBX_REPONDRE_A': 'http://example.com/callback',
-            'PBX_AUTOSEULE': 'N'
+            'PBX_AUTOSEULE': 'N',
         }
 
         form_params = {}
         for node in root:
             self.assertIn(node.attrib['type'], ('hidden', 'submit'))
             if node.attrib['type'] == 'submit':
-                self.assertEqual(set(node.attrib.keys()), set(['type', 'value']))
+                self.assertEqual(set(node.attrib.keys()), {'type', 'value'})
             if node.attrib['type'] == 'hidden':
-                self.assertEqual(set(node.attrib.keys()), set(['type', 'name', 'value']))
+                self.assertEqual(set(node.attrib.keys()), {'type', 'name', 'value'})
                 name = node.attrib['name']
                 form_params[name] = node.attrib['value']
         assert form_params == expected_form_values
@@ -140,12 +146,13 @@ class PayboxTests(TestCase):
             params['capture_day'] = capture_day
             backend = eopayment.Payment('paybox', params)
             transaction_id, kind, what = backend.request(
-                Decimal(amount), email=email, orderid=order_id,
-                transaction_id=transaction, time=time)
+                Decimal(amount), email=email, orderid=order_id, transaction_id=transaction, time=time
+            )
             root = ET.fromstring(str(what))
 
-            form_params = dict(
-                ((node.attrib['name'], node.attrib['value']) for node in root if node.attrib['type'] == 'hidden'))
+            form_params = {
+                node.attrib['name']: node.attrib['value'] for node in root if node.attrib['type'] == 'hidden'
+            }
             self.assertIn('PBX_DIFF', form_params)
             self.assertEqual(form_params['PBX_DIFF'], '07')
 
@@ -153,13 +160,18 @@ class PayboxTests(TestCase):
         params = BACKEND_PARAMS.copy()
         backend = eopayment.Payment('paybox', params)
         transaction_id, kind, what = backend.request(
-            Decimal(amount), email=email, orderid=order_id,
-            transaction_id=transaction, time=time, capture_day='2')
+            Decimal(amount),
+            email=email,
+            orderid=order_id,
+            transaction_id=transaction,
+            time=time,
+            capture_day='2',
+        )
         root = ET.fromstring(str(what))
 
-        form_params = dict(((
-            node.attrib['name'], node.attrib['value']) for node in root
-            if node.attrib['type'] == 'hidden'))
+        form_params = {
+            node.attrib['name']: node.attrib['value'] for node in root if node.attrib['type'] == 'hidden'
+        }
         self.assertIn('PBX_DIFF', form_params)
         self.assertEqual(form_params['PBX_DIFF'], '02')
 
@@ -169,13 +181,18 @@ class PayboxTests(TestCase):
         params['capture_day'] = '7'
         backend = eopayment.Payment('paybox', params)
         transaction_id, kind, what = backend.request(
-            Decimal(amount), email=email, orderid=order_id,
-            transaction_id=transaction, time=time, capture_day='2')
+            Decimal(amount),
+            email=email,
+            orderid=order_id,
+            transaction_id=transaction,
+            time=time,
+            capture_day='2',
+        )
         root = ET.fromstring(str(what))
 
-        form_params = dict(((
-            node.attrib['name'], node.attrib['value']) for node in root
-            if node.attrib['type'] == 'hidden'))
+        form_params = {
+            node.attrib['name']: node.attrib['value'] for node in root if node.attrib['type'] == 'hidden'
+        }
         self.assertIn('PBX_DIFF', form_params)
         self.assertEqual(form_params['PBX_DIFF'], '02')
 
@@ -190,12 +207,13 @@ class PayboxTests(TestCase):
         params['capture_mode'] = 'AUTHOR_CAPTURE'
         backend = eopayment.Payment('paybox', params)
         transaction_id, kind, what = backend.request(
-            Decimal(amount), email=email, orderid=order_id,
-            transaction_id=transaction, time=time)
+            Decimal(amount), email=email, orderid=order_id, transaction_id=transaction, time=time
+        )
         root = ET.fromstring(str(what))
 
-        form_params = dict(
-            ((node.attrib['name'], node.attrib['value']) for node in root if node.attrib['type'] == 'hidden'))
+        form_params = {
+            node.attrib['name']: node.attrib['value'] for node in root if node.attrib['type'] == 'hidden'
+        }
         self.assertEqual(form_params['PBX_AUTOSEULE'], 'O')
 
     def test_response(self):
@@ -209,7 +227,8 @@ class PayboxTests(TestCase):
             'code_autorisation': 'A',
             'erreur': '00000',
             'date_transaction': '20200101',
-            'heure_transaction': '01:01:01'}
+            'heure_transaction': '01:01:01',
+        }
         response = backend.response(urllib.urlencode(data))
         self.assertEqual(response.order_id, reference)
         assert not response.signed
@@ -230,20 +249,22 @@ class PayboxTests(TestCase):
                 'reference': ['830657461681'],
             }
             backend_raw_response = (
-                u'NUMTRANS=0013989865&NUMAPPEL=0030378572&NUMQUESTION=0013989862'
-                u'&SITE=1999888&RANG=32&AUTORISATION=XXXXXX&CODEREPONSE=00000'
-                u'&COMMENTAIRE=Demande traitée avec succès&REFABONNE=&PORTEUR='
+                'NUMTRANS=0013989865&NUMAPPEL=0030378572&NUMQUESTION=0013989862'
+                '&SITE=1999888&RANG=32&AUTORISATION=XXXXXX&CODEREPONSE=00000'
+                '&COMMENTAIRE=Demande traitée avec succès&REFABONNE=&PORTEUR='
             )
-            backend_expected_response = {"CODEREPONSE": "00000",
-                                         "RANG": "32",
-                                         "AUTORISATION": "XXXXXX",
-                                         "NUMTRANS": "0013989865",
-                                         "PORTEUR": "",
-                                         "COMMENTAIRE": u"Demande traitée avec succès",
-                                         "SITE": "1999888",
-                                         "NUMAPPEL": "0030378572",
-                                         "REFABONNE": "",
-                                         "NUMQUESTION": "0013989862"}
+            backend_expected_response = {
+                "CODEREPONSE": "00000",
+                "RANG": "32",
+                "AUTORISATION": "XXXXXX",
+                "NUMTRANS": "0013989865",
+                "PORTEUR": "",
+                "COMMENTAIRE": "Demande traitée avec succès",
+                "SITE": "1999888",
+                "NUMAPPEL": "0030378572",
+                "REFABONNE": "",
+                "NUMQUESTION": "0013989862",
+            }
 
             with mock.patch('eopayment.paybox.requests.post') as requests_post:
                 response = mock.Mock(status_code=200, text=backend_raw_response)
@@ -266,7 +287,7 @@ class PayboxTests(TestCase):
                     'REFERENCE': '830657461681',
                     'RANG': backend.backend.rang,
                     'SITE': backend.backend.site,
-                    'DEVISE': backend.backend.devise
+                    'DEVISE': backend.backend.devise,
                 }
                 self.assertEqual(params_sent, expected_params)
                 self.assertEqual(backend_response, backend_expected_response)
@@ -280,7 +301,7 @@ class PayboxTests(TestCase):
                     self.assertEqual(requests_post.call_args[0][0], 'https://ppps.paybox.com/PPPS.php')
 
                 with mock.patch('eopayment.paybox.requests.post') as requests_post:
-                    error_response = u"""CODEREPONSE=00015&COMMENTAIRE=PAYBOX : Transaction non trouvée"""
+                    error_response = """CODEREPONSE=00015&COMMENTAIRE=PAYBOX : Transaction non trouvée"""
                     response = mock.Mock(status_code=200, text=error_response)
                     requests_post.return_value = response
                     self.assertRaisesRegex(
@@ -288,7 +309,8 @@ class PayboxTests(TestCase):
                         'Transaction non trouvée',
                         getattr(backend, operation_name),
                         Decimal('10'),
-                        bank_data)
+                        bank_data,
+                    )
 
     def test_validate_payment(self):
         params = BACKEND_PARAMS.copy()
@@ -297,12 +319,12 @@ class PayboxTests(TestCase):
         bank_data = {
             'numero_transaction': ['13957441'],
             'numero_appel': ['30310733'],
-            'reference': ['830657461681']
+            'reference': ['830657461681'],
         }
         backend_raw_response = (
-            u'NUMTRANS=0013989865&NUMAPPEL=0030378572&NUMQUESTION=0013989862'
-            u'&SITE=1999888&RANG=32&AUTORISATION=XXXXXX&CODEREPONSE=00000'
-            u'&COMMENTAIRE=Demande traitée avec succès&REFABONNE=&PORTEUR='
+            'NUMTRANS=0013989865&NUMAPPEL=0030378572&NUMQUESTION=0013989862'
+            '&SITE=1999888&RANG=32&AUTORISATION=XXXXXX&CODEREPONSE=00000'
+            '&COMMENTAIRE=Demande traitée avec succès&REFABONNE=&PORTEUR='
         )
 
         with mock.patch('eopayment.paybox.requests.post') as requests_post:
@@ -334,15 +356,12 @@ FBFKOZhgBJnkC+l6+XhT4aYWKaQ4ocmOMV92yjeXTE4='''
         backend = eopayment.Payment('paybox', params)
 
         transaction_id, kind, what = backend.request(
-            Decimal(amount),
-            email=email,
-            orderid=order_id,
-            transaction_id=transaction,
-            time=time)
+            Decimal(amount), email=email, orderid=order_id, transaction_id=transaction, time=time
+        )
         root = ET.fromstring(str(what))
-        form_params = dict((
-            (node.attrib['name'], node.attrib['value']) for node in root
-            if node.attrib['type'] == 'hidden'))
+        form_params = {
+            node.attrib['name']: node.attrib['value'] for node in root if node.attrib['type'] == 'hidden'
+        }
         self.assertIn('PBX_AUTOSEULE', form_params)
         self.assertEqual(form_params['PBX_AUTOSEULE'], 'N')
 
@@ -352,10 +371,46 @@ FBFKOZhgBJnkC+l6+XhT4aYWKaQ4ocmOMV92yjeXTE4='''
             orderid=order_id,
             transaction_id=transaction,
             time=time,
-            manual_validation=True)
+            manual_validation=True,
+        )
         root = ET.fromstring(str(what))
-        form_params = dict((
-            (node.attrib['name'], node.attrib['value']) for node in root
-            if node.attrib['type'] == 'hidden'))
+        form_params = {
+            node.attrib['name']: node.attrib['value'] for node in root if node.attrib['type'] == 'hidden'
+        }
         self.assertIn('PBX_AUTOSEULE', form_params)
         self.assertEqual(form_params['PBX_AUTOSEULE'], 'O')
+
+    def test_invalid_signature(self):
+        backend = eopayment.Payment('paybox', BACKEND_PARAMS)
+        order_id = '20160216'
+        transaction = '1234'
+        reference = '%s!%s' % (transaction, order_id)
+        data = {
+            'montant': '4242',
+            'reference': reference,
+            'code_autorisation': 'A',
+            'erreur': '00000',
+            'date_transaction': '20200101',
+            'heure_transaction': '01:01:01',
+            'signature': 'a',
+        }
+        with pytest.raises(eopayment.ResponseError, match='invalid signature'):
+            backend.response(urllib.urlencode(data))
+
+
+@pytest.mark.parametrize(
+    'name,value,result',
+    [
+        ('shared_secret', '1f', True),
+        ('shared_secret', '1fxx', False),
+        ('shared_secret', '1fa', False),
+        ('shared_secret', '1fa2', True),
+    ],
+)
+def test_param_validation(name, value, result):
+    for param in paybox.Payment.description['parameters']:
+        if param['name'] == name:
+            assert param['validation'](value) is result
+            break
+    else:
+        assert False, 'param %s not found' % name
