@@ -1,4 +1,3 @@
-# coding: utf-8
 #
 # eopayment - online payment library
 # Copyright (C) 2011-2020 Entr'ouvert
@@ -16,24 +15,20 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import print_function, unicode_literals
 
 import datetime
 import json
-import lxml.etree as ET
-import mock
-
-import pytz
+from unittest import mock
 
 import httmock
+import lxml.etree as ET
 import pytest
-
+import pytz
 from zeep.plugins import HistoryPlugin
 
 import eopayment
 from eopayment.payfip_ws import PayFiP, PayFiPError, normalize_objet
 
-
 NUMCLI = '090909'
 NOTIF_URL = 'https://notif.payfip.example.com/'
 REDIRECT_URL = 'https://redirect.payfip.example.com/'
@@ -56,7 +51,7 @@ def freezer(freezer):
     return freezer
 
 
-class PayFiPHTTMock(object):
+class PayFiPHTTMock:
     def __init__(self, history_name):
         history_path = 'tests/data/payfip-%s.json' % history_name
         with open(history_path) as fd:
@@ -77,13 +72,21 @@ def history_name(request):
 
 
 @pytest.fixture
-def history(history_name, request):
+def history(history_name, request, zeep_history_plugin):
     if 'update_data' not in request.keywords:
         history_mock = PayFiPHTTMock(history_name)
         with httmock.HTTMock(history_mock.mock):
             yield history_mock
     else:
         yield None
+        history_path = 'tests/data/payfip-%s.json' % history_name
+        d = [
+            (xmlindent(exchange['sent']['envelope']), xmlindent(exchange['received']['envelope']))
+            for exchange in zeep_history_plugin._buffer
+        ]
+        content = json.dumps(d)
+        with open(history_path, 'wb') as fd:
+            fd.write(content)
 
 
 @pytest.fixture
@@ -97,39 +100,42 @@ def get_idop():
 def backend(request):
     with mock.patch('eopayment.payfip_ws.Payment._generate_refdet') as _generate_refdet:
         _generate_refdet.return_value = REFDET_GEN
-        yield eopayment.Payment('payfip_ws', {
-            'numcli': '090909',
-            'automatic_return_url': NOTIF_URL,
-            'normal_return_url': REDIRECT_URL,
-        })
+        yield eopayment.Payment(
+            'payfip_ws',
+            {
+                'numcli': '090909',
+                'automatic_return_url': NOTIF_URL,
+                'normal_return_url': REDIRECT_URL,
+            },
+        )
+
+
+@httmock.urlmatch()
+def raise_on_request(url, request):
+    # ensure we do not access network
+    from requests.exceptions import RequestException
+
+    raise RequestException('huhu')
 
 
 @pytest.fixture
-def payfip(history, history_name, request):
-    history = HistoryPlugin()
+def zeep_history_plugin():
+    return HistoryPlugin()
 
-    @httmock.urlmatch()
-    def raise_on_request(url, request):
-        # ensure we do not access network
-        from requests.exceptions import RequestException
-        raise RequestException('huhu')
 
+@pytest.fixture
+def payfip(zeep_history_plugin):
     with httmock.HTTMock(raise_on_request):
-        payfip = PayFiP(wsdl_url='./eopayment/resource/PaiementSecuriseService.wsdl',
-                        zeep_client_kwargs={'plugins': [history]})
+        payfip = PayFiP(
+            wsdl_url='./eopayment/resource/PaiementSecuriseService.wsdl',
+            zeep_client_kwargs={'plugins': [zeep_history_plugin]},
+        )
     yield payfip
 
-    # add @pytest.mark.update_data to test to update fixtures data
-    if 'update_data' in request.keywords:
-        history_path = 'tests/data/payfip-%s.json' % history_name
-        d = [
-            (xmlindent(exchange['sent']['envelope']),
-             xmlindent(exchange['received']['envelope']))
-            for exchange in history._buffer
-        ]
-        content = json.dumps(d)
-        with open(history_path, 'wb') as fd:
-            fd.write(content)
+
+@pytest.fixture
+def payfip_history(history, payfip, zeep_history_plugin, request):
+    yield
 
 
 def set_history_name(name):
@@ -137,18 +143,20 @@ def set_history_name(name):
     def decorator(func):
         func.history_name = name
         return func
+
     return decorator
 
+
 # pytestmark = pytest.mark.update_data
 
 
-def test_get_client_info(payfip):
+def test_get_client_info(history, payfip):
     result = payfip.get_info_client(NUMCLI)
     assert result.numcli == NUMCLI
     assert result.libelleN2 == 'POUETPOUET'
 
 
-def test_get_idop_ok(payfip):
+def test_get_idop_ok(history, payfip):
     result = payfip.get_idop(
         numcli=NUMCLI,
         exer='2019',
@@ -158,11 +166,12 @@ def test_get_idop_ok(payfip):
         objet='coucou',
         url_notification=NOTIF_URL,
         url_redirect=REDIRECT_URL,
-        saisie='T')
+        saisie='T',
+    )
     assert result == 'cc0cb210-1cd4-11ea-8cca-0213ad91a103'
 
 
-def test_get_idop_refdet_error(payfip):
+def test_get_idop_refdet_error(history, payfip):
     with pytest.raises(PayFiPError, match='.*R3.*Le format.*REFDET.*conforme'):
         payfip.get_idop(
             numcli=NUMCLI,
@@ -173,10 +182,11 @@ def test_get_idop_refdet_error(payfip):
             objet='coucou',
             url_notification='https://notif.payfip.example.com/',
             url_redirect='https://redirect.payfip.example.com/',
-            saisie='T')
+            saisie='T',
+        )
 
 
-def test_get_idop_adresse_mel_incorrect(payfip):
+def test_get_idop_adresse_mel_incorrect(payfip, payfip_history):
     with pytest.raises(PayFiPError, match='.*A2.*Adresse.*incorrecte'):
         payfip.get_idop(
             numcli=NUMCLI,
@@ -187,10 +197,11 @@ def test_get_idop_adresse_mel_incorrect(payfip):
             objet='coucou',
             url_notification='https://notif.payfip.example.com/',
             url_redirect='https://redirect.payfip.example.com/',
-            saisie='T')
+            saisie='T',
+        )
 
 
-def test_get_info_paiement_ok(payfip):
+def test_get_info_paiement_ok(history, payfip):
     result = payfip.get_info_paiement('cc0cb210-1cd4-11ea-8cca-0213ad91a103')
     assert {k: result[k] for k in result} == {
         'dattrans': '12122019',
@@ -204,11 +215,11 @@ def test_get_info_paiement_ok(payfip):
         'objet': 'coucou',
         'refdet': 'EFEFAEFG',
         'resultrans': 'V',
-        'saisie': 'T'
+        'saisie': 'T',
     }
 
 
-def test_get_info_paiement_P1(payfip, freezer):
+def test_get_info_paiement_P1(history, payfip, freezer):
     # idop par pas encore reçu par la plate-forme ou déjà nettoyé (la nuit)
     with pytest.raises(PayFiPError, match='.*P1.*IdOp incorrect.*'):
         payfip.get_info_paiement('cc0cb210-1cd4-11ea-8cca-0213ad91a103')
@@ -216,6 +227,7 @@ def test_get_info_paiement_P1(payfip, freezer):
 
 @set_history_name('test_get_info_paiement_P1')
 def test_P1_and_payment_status(history, backend):
+    assert backend.has_payment_status
     response = backend.payment_status(transaction_id='cc0cb210-1cd4-11ea-8cca-0213ad91a103')
     assert response.result == eopayment.EXPIRED
 
@@ -223,14 +235,18 @@ def test_P1_and_payment_status(history, backend):
 @set_history_name('test_get_info_paiement_P1')
 def test_P1_and_payment_status_utc_aware_now(history, backend):
     utc_now = datetime.datetime.now(pytz.utc)
-    response = backend.payment_status(transaction_id='cc0cb210-1cd4-11ea-8cca-0213ad91a103', transaction_date=utc_now)
+    response = backend.payment_status(
+        transaction_id='cc0cb210-1cd4-11ea-8cca-0213ad91a103', transaction_date=utc_now
+    )
     assert response.result == eopayment.EXPIRED
 
 
 @set_history_name('test_get_info_paiement_P1')
 def test_P1_and_payment_status_utc_naive_now(history, backend):
     now = datetime.datetime.now()
-    response = backend.payment_status(transaction_id='cc0cb210-1cd4-11ea-8cca-0213ad91a103', transaction_date=now)
+    response = backend.payment_status(
+        transaction_id='cc0cb210-1cd4-11ea-8cca-0213ad91a103', transaction_date=now
+    )
     assert response.result == eopayment.EXPIRED
 
 
@@ -238,84 +254,100 @@ def test_P1_and_payment_status_utc_naive_now(history, backend):
 def test_P1_and_payment_status_utc_aware_now_later(history, backend, freezer):
     utc_now = datetime.datetime.now(pytz.utc)
     freezer.move_to(datetime.timedelta(minutes=25))
-    response = backend.payment_status(transaction_id='cc0cb210-1cd4-11ea-8cca-0213ad91a103', transaction_date=utc_now)
+    response = backend.payment_status(
+        transaction_id='cc0cb210-1cd4-11ea-8cca-0213ad91a103', transaction_date=utc_now
+    )
     assert response.result == eopayment.EXPIRED
 
 
 @set_history_name('test_get_info_paiement_P1')
-def test_P1_and_payment_status_utc_naive_now_later(payfip, backend, freezer):
+def test_P1_and_payment_status_utc_naive_now_later(history, payfip, backend, freezer):
     now = datetime.datetime.now()
     freezer.move_to(datetime.timedelta(minutes=25))
-    response = backend.payment_status(transaction_id='cc0cb210-1cd4-11ea-8cca-0213ad91a103', transaction_date=now)
+    response = backend.payment_status(
+        transaction_id='cc0cb210-1cd4-11ea-8cca-0213ad91a103', transaction_date=now
+    )
     assert response.result == eopayment.EXPIRED
 
 
-def test_get_info_paiement_P5(payfip):
+def test_get_info_paiement_P5(history, payfip):
     # idop reçu par la plate-forme mais transaction en cours
     with pytest.raises(PayFiPError, match='.*P5.*sultat de la transaction non connu.*'):
         payfip.get_info_paiement('cc0cb210-1cd4-11ea-8cca-0213ad91a103')
 
 
 @set_history_name('test_get_info_paiement_P5')
-def test_P5_and_payment_status(payfip, backend, freezer):
+def test_P5_and_payment_status(history, payfip, backend, freezer):
     response = backend.payment_status(transaction_id='cc0cb210-1cd4-11ea-8cca-0213ad91a103')
     assert response.result == eopayment.WAITING
 
 
 @set_history_name('test_get_info_paiement_P5')
-def test_P5_and_payment_status_utc_aware_now(payfip, backend, freezer):
+def test_P5_and_payment_status_utc_aware_now(history, payfip, backend, freezer):
     utc_now = datetime.datetime.now(pytz.utc)
-    response = backend.payment_status(transaction_id='cc0cb210-1cd4-11ea-8cca-0213ad91a103', transaction_date=utc_now)
+    response = backend.payment_status(
+        transaction_id='cc0cb210-1cd4-11ea-8cca-0213ad91a103', transaction_date=utc_now
+    )
     assert response.result == eopayment.WAITING
 
 
 @set_history_name('test_get_info_paiement_P5')
-def test_P5_and_payment_status_utc_naive_now(payfip, backend, freezer):
+def test_P5_and_payment_status_utc_naive_now(history, payfip, backend, freezer):
     now = datetime.datetime.now()
-    response = backend.payment_status(transaction_id='cc0cb210-1cd4-11ea-8cca-0213ad91a103', transaction_date=now)
+    response = backend.payment_status(
+        transaction_id='cc0cb210-1cd4-11ea-8cca-0213ad91a103', transaction_date=now
+    )
     assert response.result == eopayment.WAITING
 
 
 @set_history_name('test_get_info_paiement_P5')
-def test_P5_and_payment_status_utc_aware_now_later(payfip, backend, freezer):
+def test_P5_and_payment_status_utc_aware_now_later(history, payfip, backend, freezer):
     utc_now = datetime.datetime.now(pytz.utc)
     freezer.move_to(datetime.timedelta(minutes=25))
-    response = backend.payment_status(transaction_id='cc0cb210-1cd4-11ea-8cca-0213ad91a103', transaction_date=utc_now)
+    response = backend.payment_status(
+        transaction_id='cc0cb210-1cd4-11ea-8cca-0213ad91a103', transaction_date=utc_now
+    )
     assert response.result == eopayment.EXPIRED
 
 
 @set_history_name('test_get_info_paiement_P5')
-def test_P5_and_payment_status_utc_naive_now_later(payfip, backend, freezer):
+def test_P5_and_payment_status_utc_naive_now_later(history, payfip, backend, freezer):
     now = datetime.datetime.now()
     freezer.move_to(datetime.timedelta(minutes=25))
-    response = backend.payment_status(transaction_id='cc0cb210-1cd4-11ea-8cca-0213ad91a103', transaction_date=now)
+    response = backend.payment_status(
+        transaction_id='cc0cb210-1cd4-11ea-8cca-0213ad91a103', transaction_date=now
+    )
     assert response.result == eopayment.EXPIRED
 
 
-def test_payment_ok(payfip, backend):
+def test_payment_ok(history, payfip, backend):
     payment_id, kind, url = backend.request(
         amount='10.00',
         email=MEL,
         # make test deterministic
-        refdet='201912261758460053903194')
+        refdet='201912261758460053903194',
+    )
 
     assert payment_id == 'cc0cb210-1cd4-11ea-8cca-0213ad91a103'
     assert kind == eopayment.URL
-    assert url == 'https://www.tipi.budget.gouv.fr/tpa/paiementws.web?idop=cc0cb210-1cd4-11ea-8cca-0213ad91a103'
+    assert url == 'https://www.payfip.gouv.fr/tpa/paiementws.web?idop=cc0cb210-1cd4-11ea-8cca-0213ad91a103'
 
     response = backend.response('idop=%s' % payment_id)
     assert response.result == eopayment.PAID
     assert response.bank_status == 'paid CB'
     assert response.order_id == payment_id
     assert response.transaction_id == (
-        '201912261758460053903194 cc0cb210-1cd4-11ea-8cca-0213ad91a103 112233445566-tip')
+        '201912261758460053903194 cc0cb210-1cd4-11ea-8cca-0213ad91a103 112233445566-tip'
+    )
 
 
 @set_history_name('test_payment_ok')
 def test_payment_status_ok(history, backend, freezer):
     history.counter = 1  # only the response
     now = datetime.datetime.now()
-    response = backend.payment_status(transaction_id='cc0cb210-1cd4-11ea-8cca-0213ad91a103', transaction_date=now)
+    response = backend.payment_status(
+        transaction_id='cc0cb210-1cd4-11ea-8cca-0213ad91a103', transaction_date=now
+    )
     assert response.result == eopayment.PAID
 
 
@@ -324,11 +356,12 @@ def test_payment_denied(history, backend):
         amount='10.00',
         email=MEL,
         # make test deterministic
-        refdet='201912261758460053903194')
+        refdet='201912261758460053903194',
+    )
 
     assert payment_id == 'cc0cb210-1cd4-11ea-8cca-0213ad91a103'
     assert kind == eopayment.URL
-    assert url == 'https://www.tipi.budget.gouv.fr/tpa/paiementws.web?idop=cc0cb210-1cd4-11ea-8cca-0213ad91a103'
+    assert url == 'https://www.payfip.gouv.fr/tpa/paiementws.web?idop=cc0cb210-1cd4-11ea-8cca-0213ad91a103'
 
     response = backend.response('idop=%s' % payment_id)
     assert response.result == eopayment.DENIED
@@ -341,7 +374,9 @@ def test_payment_denied(history, backend):
 def test_payment_status_denied(history, backend, freezer):
     history.counter = 1  # only the response
     now = datetime.datetime.now()
-    response = backend.payment_status(transaction_id='cc0cb210-1cd4-11ea-8cca-0213ad91a103', transaction_date=now)
+    response = backend.payment_status(
+        transaction_id='cc0cb210-1cd4-11ea-8cca-0213ad91a103', transaction_date=now
+    )
     assert response.result == eopayment.DENIED
 
 
@@ -350,11 +385,12 @@ def test_payment_cancelled(history, backend):
         amount='10.00',
         email=MEL,
         # make test deterministic
-        refdet='201912261758460053903194')
+        refdet='201912261758460053903194',
+    )
 
     assert payment_id == 'cc0cb210-1cd4-11ea-8cca-0213ad91a103'
     assert kind == eopayment.URL
-    assert url == 'https://www.tipi.budget.gouv.fr/tpa/paiementws.web?idop=cc0cb210-1cd4-11ea-8cca-0213ad91a103'
+    assert url == 'https://www.payfip.gouv.fr/tpa/paiementws.web?idop=cc0cb210-1cd4-11ea-8cca-0213ad91a103'
 
     response = backend.response('idop=%s' % payment_id)
     assert response.result == eopayment.CANCELLED
@@ -367,7 +403,9 @@ def test_payment_cancelled(history, backend):
 def test_payment_status_cancelled(history, backend, freezer):
     history.counter = 1  # only the response
     now = datetime.datetime.now()
-    response = backend.payment_status(transaction_id='cc0cb210-1cd4-11ea-8cca-0213ad91a103', transaction_date=now)
+    response = backend.payment_status(
+        transaction_id='cc0cb210-1cd4-11ea-8cca-0213ad91a103', transaction_date=now
+    )
     assert response.result == eopayment.CANCELLED
 
 
@@ -385,7 +423,8 @@ def test_refdet_exer(get_idop, backend):
         email=MEL,
         # make test deterministic
         exer=EXER,
-        refdet=REFDET)
+        refdet=REFDET,
+    )
 
     assert payment_id == 'idop-1234'
     kwargs = get_idop.call_args[1]
@@ -411,7 +450,8 @@ def test_transaction_id_orderid_subject(get_idop, backend):
         exer=EXER,
         transaction_id='TR12345',
         orderid='F20190003',
-        subject='Précompte famille #1234')
+        subject='Précompte famille #1234',
+    )
 
     assert payment_id == 'idop-1234'
     kwargs = get_idop.call_args[1]
@@ -437,7 +477,8 @@ def test_invalid_transaction_id_valid_orderid(get_idop, backend):
         exer=EXER,
         transaction_id='TR-12345',
         orderid='F20190003',
-        subject='Précompte famille #1234')
+        subject='Précompte famille #1234',
+    )
 
     assert payment_id == 'idop-1234'
     kwargs = get_idop.call_args[1]
@@ -463,7 +504,8 @@ def test_invalid_transaction_id_invalid_orderid(get_idop, backend):
         exer=EXER,
         transaction_id='TR-12345',
         orderid='F/20190003',
-        subject='Précompte famille #1234')
+        subject='Précompte famille #1234',
+    )
 
     assert payment_id == 'idop-1234'
     kwargs = get_idop.call_args[1]
@@ -479,3 +521,26 @@ def test_invalid_transaction_id_invalid_orderid(get_idop, backend):
         'url_notification': NOTIF_URL,
         'url_redirect': REDIRECT_URL,
     }
+
+
+def test_get_min_time_between_transactions(backend):
+    assert backend.get_min_time_between_transactions() == 20 * 60
+
+
+def test_get_minimal_amount(backend):
+    assert backend.get_minimal_amount() is not None
+
+
+def test_get_maximal_amount(backend):
+    assert backend.get_maximal_amount() is not None
+
+
+def test_request_error(payfip, backend):
+    with pytest.raises(PayFiPError):
+        with httmock.HTTMock(raise_on_request):
+            payment_id, kind, url = backend.request(
+                amount='10.00',
+                email=MEL,
+                # make test deterministic
+                refdet='201912261758460053903194',
+            )
