@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # eopayment - online payment library
 # Copyright (C) 2011-2020 Entr'ouvert
 #
@@ -16,32 +15,32 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 
-import eopayment
 import pytest
 
+import eopayment
+
 
 def test_build_request():
     backend = eopayment.Payment('sips2', {})
-    transaction, f, form = backend.request(amount=u'12', last_name=u'Foo',
-                                           first_name=u'Félix000000')
+    transaction, f, form = backend.request(amount='12', last_name='Foo', first_name='Félix000000')
     data = [f for f in form.fields if f['name'] == 'Data']
-    assert u'lix000000' not in data[0]['value']
+    assert 'lix000000' not in data[0]['value']
 
-    transaction, f, form = backend.request(amount=u'12')
+    transaction, f, form = backend.request(amount='12')
     data = [f for f in form.fields if f['name'] == 'Data']
     assert 'statementReference=%s' % transaction in data[0]['value']
 
-    transaction, f, form = backend.request(amount=u'12', info1='foobar')
+    transaction, f, form = backend.request(amount='12', info1='foobar')
     data = [f for f in form.fields if f['name'] == 'Data']
     assert 'statementReference=foobar' in data[0]['value']
 
-    transaction, f, form = backend.request(amount=u'12', info1='foobar', capture_day=u'1')
+    transaction, f, form = backend.request(amount='12', info1='foobar', capture_day='1')
     data = [f for f in form.fields if f['name'] == 'Data']
     assert 'captureDay=1' in data[0]['value']
 
 
 def test_options():
-    payment = eopayment.Payment('sips2', {'capture_mode': u'VALIDATION'})
+    payment = eopayment.Payment('sips2', {'capture_mode': 'VALIDATION'})
     assert payment.backend.get_data()['captureMode'] == 'VALIDATION'
 
     payment = eopayment.Payment('sips2', {})
