@@ -16,13 +16,13 @@
 
 import datetime
 from decimal import Decimal
-from six.moves.urllib.parse import urlparse, parse_qs
 
+import pytest
 import pytz
+from six.moves.urllib.parse import parse_qs, urlparse
 
 import eopayment
 import eopayment.tipi
-import pytest
 
 
 def test_tipi():
@@ -34,7 +34,8 @@ def test_tipi():
         objet='tout a fait',
         email='info@entrouvert.com',
         urlcl='http://example.com/tipi/test',
-        saisie='T')
+        saisie='T',
+    )
     assert eopayment.tipi.Payment.REFDET_RE.match(payment_id) is not None
     parsed_qs = parse_qs(urlparse(url).query)
     assert parsed_qs['objet'][0].startswith('tout a fait')
@@ -47,7 +48,8 @@ def test_tipi():
 
     response = p.response(
         'objet=tout+a+fait&montant=12312&saisie=T&mel=info%40entrouvert.com'
-        '&numcli=12345&exer=9999&refdet=999900000000999999&resultrans=P')
+        '&numcli=12345&exer=9999&refdet=999900000000999999&resultrans=P'
+    )
     assert response.signed  # ...
     assert response.order_id == '999900000000999999'
     assert response.transaction_id == '999900000000999999'
@@ -60,10 +62,8 @@ def test_tipi():
 def test_tipi_no_orderid_no_refdet():
     p = eopayment.Payment('tipi', {'numcli': '12345'})
     payment_id, kind, url = p.request(
-        amount=Decimal('123.12'),
-        exer=9999,
-        email='info@entrouvert.com',
-        saisie='T')
+        amount=Decimal('123.12'), exer=9999, email='info@entrouvert.com', saisie='T'
+    )
     assert eopayment.tipi.Payment.REFDET_RE.match(payment_id) is not None
     parsed_qs = parse_qs(urlparse(url).query)
     assert 'objet' not in parsed_qs
@@ -72,15 +72,16 @@ def test_tipi_no_orderid_no_refdet():
     assert parsed_qs['mel'] == ['info@entrouvert.com']
     assert parsed_qs['numcli'] == ['12345']
     assert parsed_qs['exer'] == ['9999']
-    assert parsed_qs['refdet'][0].startswith(datetime.datetime.now(pytz.timezone('Europe/Paris')).strftime('%Y%m%d'))
+    assert parsed_qs['refdet'][0].startswith(
+        datetime.datetime.now(pytz.timezone('Europe/Paris')).strftime('%Y%m%d')
+    )
 
 
 def test_tipi_orderid_refdef_compatible():
     p = eopayment.Payment('tipi', {'numcli': '12345', 'saisie': 'A'})
     payment_id, kind, url = p.request(
-        amount=Decimal('123.12'),
-        email='info@entrouvert.com',
-        orderid='F121212')
+        amount=Decimal('123.12'), email='info@entrouvert.com', orderid='F121212'
+    )
     assert eopayment.tipi.Payment.REFDET_RE.match(payment_id)
     expected_url = urlparse(eopayment.tipi.TIPI_URL)
     parsed_url = urlparse(url)
@@ -98,10 +99,8 @@ def test_tipi_orderid_refdef_compatible():
 def test_tipi_orderid_not_refdef_compatible():
     p = eopayment.Payment('tipi', {'numcli': '12345', 'saisie': 'A'})
     payment_id, kind, url = p.request(
-        amount=Decimal('123.12'),
-        email='info@entrouvert.com',
-        objet='coucou',
-        orderid='F12-12-12')
+        amount=Decimal('123.12'), email='info@entrouvert.com', objet='coucou', orderid='F12-12-12'
+    )
     assert eopayment.tipi.Payment.REFDET_RE.match(payment_id) is not None
     expected_url = urlparse(eopayment.tipi.TIPI_URL)
     parsed_url = urlparse(url)
@@ -115,3 +114,16 @@ def test_tipi_orderid_not_refdef_compatible():
     assert parsed_qs['refdet'][0].startswith(datetime.datetime.now().strftime('%Y%m%d'))
     assert 'coucou' in parsed_qs['objet'][0]
     assert 'F12-12-12' in parsed_qs['objet'][0]
+
+
+@pytest.fixture
+def payment():
+    return eopayment.Payment('tipi', {'numcli': '12345'})
+
+
+def test_get_minimal_amount(payment):
+    assert payment.get_minimal_amount() is not None
+
+
+def test_get_maximal_amount(payment):
+    assert payment.get_maximal_amount() is not None
